## Usage
        => Create folders named `plugins`, `assistant` and `resources`.<br/>
        => Add your plugins in the `plugins` folder and others accordingly.<br/>
        => Create a `.env` file with `API_ID`, `API_HASH`, `SESSION`, 
           as mandatory environment variables<br/>
        => Run `python -m GODBOY` to start the bot.<br/>
        
    
        

